import os

from celery import Celery
from celery.schedules import crontab
from celery.utils.log import get_task_logger

from .extractors import ExtractorAllURLs 


# Set the default Django settings module for the 'celery' program.
APP_ENV = os.getenv("APP_ENV", "dev")
os.environ.setdefault("DJANGO_SETTINGS_MODULE", f"agenda_culturel.settings.{APP_ENV}")

app = Celery("agenda_culturel")

logger = get_task_logger(__name__)


# Using a string here means the worker doesn't have to serialize
# the configuration object to child processes.
# - namespace='CELERY' means all celery-related configuration keys
#   should have a `CELERY_` prefix.
app.config_from_object("django.conf:settings", namespace="CELERY")

# Load task modules from all registered Django apps.
app.autodiscover_tasks()


@app.task(bind=True)
def import_events_from_json(self, json, taskid):
    from agenda_culturel.models import Event

    logger.info("Import events from json: {}".format(taskid))

    # TODO


@app.task(bind=True)
def import_events_from_url(self, source, browsable_url, taskid):
    from agenda_culturel.models import Event

    logger.info("Import events from url: {} {}".format(source, taskid))
    
    # TODO


app.conf.timezone = "Europe/Paris"
